@@ -70,7 +70,10 @@ forestcoxUI <- function(id, label = "forestplot") {
     uiOutput(ns("cov_tbsub")),
     uiOutput(ns("time_tbsub")),
     checkboxInput(ns("cmp_risk_check"), "Competing Risk Analysis(Fine-Gray)"),
-    uiOutput(ns("cmp_eventtime"))
+    uiOutput(ns("cmp_eventtime")),
+    checkboxInput(ns("custom_forest"), "Custom X axis ticks in forest plot"),
+    uiOutput(ns("hr_points")),
+    uiOutput(ns("numeric_inputs"))
   )
 }
 
@@ -85,6 +88,8 @@ forestcoxUI <- function(id, label = "forestplot") {
 #' @param nfactor.limit nlevels limit in factor variable, Default: 10
 #' @param design.survey reactive survey data. default: NULL
 #' @param cluster_id cluster option variable for marginal cox model
+#' @param vec.event event variables as vector for survival analysis,  Default: NULL
+#' @param vec.time time variables as vector for survival analysis,  Default: NULL
 #' @return Shiny module server for forestcox
 #' @details Shiny module server for forestcox
 #' @examples
@@ -154,12 +159,12 @@ forestcoxUI <- function(id, label = "forestplot") {
 #' @importFrom rvg dml
 #' @importFrom officer read_pptx add_slide ph_with ph_location
 
-forestcoxServer <- function(id, data, data_label, data_varStruct = NULL, nfactor.limit = 10, design.survey = NULL, cluster_id = NULL) {
+forestcoxServer <- function(id, data, data_label, data_varStruct = NULL, nfactor.limit = 10, design.survey = NULL, cluster_id = NULL, vec.event = NULL, vec.time = NULL) {
   moduleServer(
     id,
     function(input, output, session) {
       N <- V1 <- V2 <- .N <- HR <- Lower <- Upper <- level <- val_label <- variable <- NULL
-
+      fix_et <- !is.null(vec.event) && !is.null(vec.time) && (length(vec.event) == length(vec.time))
       if (is.null(data_varStruct)) {
         data_varStruct <- reactive(list(variable = names(data())))
       }
@@ -226,7 +231,11 @@ forestcoxServer <- function(id, data, data_label, data_varStruct = NULL, nfactor
         selectInput(session$ns("group"), "Group", choices = setdiff(c(vlist()$group2_vars, vlist()$conti_vars), input$dep), selected = setdiff(c(vlist()$group2_vars, vlist()$conti_vars), c(input$dep, vlist()$factor_01vars[1]))[1])
       })
       output$dep_tbsub <- renderUI({
-        selectInput(session$ns("dep"), "Outcome", choices = vlist()$factor_01vars, selected = vlist()$factor_01vars[1])
+        if (!fix_et) {
+          selectInput(session$ns("dep"), "Outcome", choices = vlist()$factor_01vars, selected = vlist()$factor_01vars[1])
+        } else {
+          selectInput(session$ns("dep"), "Outcome", choices = vec.event, selected = vec.event[1])
+        }
       })
       output$subvar_tbsub <- renderUI({
         req(input$dep)
@@ -236,7 +245,11 @@ forestcoxServer <- function(id, data, data_label, data_varStruct = NULL, nfactor
         selectInput(session$ns("cov"), "Addtional covariates", choices = vlist()$group_vars, selected = NULL, multiple = T)
       })
       output$day_tbsub <- renderUI({
-        selectInput(session$ns("day"), "Time", choices = vlist()$conti_vars_positive, selected = vlist()$conti_vars_positive[1])
+        if (!fix_et) {
+          selectInput(session$ns("day"), "Time", choices = vlist()$conti_vars_positive, selected = vlist()$conti_vars_positive[1])
+        } else {
+          selectInput(session$ns("day"), "Time", choices = vec.time, selected = vec.time[1])
+        }
       })
       output$time_tbsub <- renderUI({
         req(input$day)
@@ -244,15 +257,64 @@ forestcoxServer <- function(id, data, data_label, data_varStruct = NULL, nfactor
         sliderInput(session$ns("time"), "Select time range", min = min(data()[[day]], na.rm = TRUE), max = max(data()[[day]], na.rm = TRUE), value = c(min(data()[[day]], na.rm = TRUE), max(data()[[day]], na.rm = TRUE)))
       })
 
-      #print(cluster_id)
 
-      output$xlim_forest <- renderUI({
-        req(tbsub)
-        data <- tbsub()
-        data <- data[!(HR == 0 | Lower == 0)]$Upper
-        numericInput(session$ns("xMax"), "max HR for forestplot", value = round(max(as.numeric(data[data != "Inf"]), na.rm = TRUE), 2))
+
+
+      if (fix_et) {
+        paired_forest <- setNames(vec.time, vec.event)
+        paired_rev_forest <- setNames(vec.event, vec.time)
+
+
+        observeEvent(input$dep, {
+          req(input$dep)
+          new_day <- paired_forest[[input$dep]]
+          if (!is.null(new_day) && new_day != input$day) {
+            updateSelectInput(session, "day", selected = new_day)
+          }
+        })
+
+        observeEvent(input$day, {
+          req(input$day)
+          new_dep <- paired_rev_forest[[input$day]]
+          if (!is.null(new_dep) && new_dep != input$dep) {
+            updateSelectInput(session, "dep", selected = new_dep)
+          }
+        })
+      }
+
+
+
+      # print(cluster_id)
+
+
+
+      observeEvent(input$custom_forest, {
+        output$hr_points <- renderUI({
+          req(input$custom_forest == TRUE)
+          tagList(
+            sliderInput(session$ns("num_points"), "select number of x axis ticks", min = 2, max = 8, value = 3)
+          )
+        })
       })
 
+      output$numeric_inputs <- renderUI({
+        req(input$num_points)
+        fluidRow(
+          lapply(seq_len(input$num_points), function(i) {
+            column(
+              width = floor(12 / input$num_points),
+              numericInput(
+                session$ns(paste0("point_", i)),
+                paste("Point", i, ":"),
+                value = 1.0
+              )
+            )
+          })
+        )
+      })
+
+
+
       observeEvent(input$cmp_risk_check, {
         output$cmp_eventtime <- renderUI({
           req(input$cmp_risk_check == TRUE)
@@ -410,6 +472,20 @@ forestcoxServer <- function(id, data, data_label, data_varStruct = NULL, nfactor
       })
 
 
+
+
+      ticks <- reactive({
+        if (is.null(input$num_points)) {
+          a <- c(0, 1, 2)
+        } else {
+          a <- sapply(seq_len(input$num_points), function(i) input[[paste0("point_", i)]])
+        }
+        return(a)
+      })
+
+
+
+
       figure <- reactive({
         group.tbsub <- input$group
         label <- data_label()
@@ -430,8 +506,6 @@ forestcoxServer <- function(id, data, data_label, data_varStruct = NULL, nfactor
         if (is.null(input$xMax) || any(is.na(xlim))) {
           xlim <- c(0, 2)
         }
-
-
         forestploter::forest(data[, .SD, .SDcols = selected_columns],
           lower = as.numeric(data$Lower),
           upper = as.numeric(data$Upper),
@@ -440,8 +514,9 @@ forestcoxServer <- function(id, data, data_label, data_varStruct = NULL, nfactor
           ref_line = 1,
           ticks_digits = 1,
           x_trans = "log",
-          xlim = xlim,
+          xlim = NULL,
           arrow_lab = c(input$arrow_left, input$arrow_right),
+          ticks_at = ticks(),
           theme = tm
         ) -> zz
 
@@ -451,6 +526,7 @@ forestcoxServer <- function(id, data, data_label, data_varStruct = NULL, nfactor
         zz$heights[(l[1] - 2):(l[1] - 1)] <- h
         return(zz)
       })
+
       res <- reactive({
         list(
           datatable(tbsub(),
@@ -463,13 +539,11 @@ forestcoxServer <- function(id, data, data_label, data_varStruct = NULL, nfactor
           figure()
         )
       })
+
       output$downloadControls <- renderUI({
         tagList(
           fluidRow(
             column(
-              3,
-              uiOutput(session$ns("xlim_forest"))
-            ), column(
               3,
               numericInput(session$ns("font"), "font-size", value = 12)
             ),
