@@ -1283,13 +1283,13 @@ jsBasicExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb)[1] <- " "
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
@@ -1358,13 +1358,13 @@ jsBasicExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb) <- c(" ", cn)
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
@@ -1428,13 +1428,13 @@ jsBasicExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb) <- c(" ", cn)
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
@@ -1494,13 +1494,13 @@ jsBasicExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb) <- c(" ", cn)
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
