@@ -1497,13 +1497,13 @@ jsPropensityExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb)[1] <- " "
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
@@ -1568,13 +1568,13 @@ jsPropensityExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb)[1] <- " "
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
@@ -1640,13 +1640,13 @@ jsPropensityExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb)[1] <- " "
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
@@ -1718,13 +1718,13 @@ jsPropensityExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb) <- c(" ", cn)
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
@@ -1790,13 +1790,13 @@ jsPropensityExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb) <- c(" ", cn)
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
@@ -1862,13 +1862,13 @@ jsPropensityExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb) <- c(" ", cn)
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
@@ -1936,13 +1936,13 @@ jsPropensityExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb) <- c(" ", cn)
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
@@ -2004,13 +2004,13 @@ jsPropensityExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb) <- c(" ", cn)
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
@@ -2072,13 +2072,13 @@ jsPropensityExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb) <- c(" ", cn)
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
@@ -2146,13 +2146,13 @@ jsPropensityExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb) <- c(" ", cn)
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
@@ -2213,13 +2213,13 @@ jsPropensityExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb) <- c(" ", cn)
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
@@ -2280,13 +2280,13 @@ jsPropensityExtAddin <- function(nfactor.limit = 20, max.filesize = 2048) {
         tb <- cbind(rn, data.frame(tb))
         colnames(tb) <- c(" ", cn)
 
-        officer::read_docx() |>
+        officer::read_docx() %>%
           body_add_flextable(
             tb %>%
               flextable() %>%
               autofit() %>%
               theme_booktabs(bold_header = TRUE)
-          ) |>
+          ) %>%
           print(target = file)
       }
     )
